@@ -20,10 +20,7 @@ import aws_cdk.custom_resources._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-gitlab-runner",
-    "1.75.17",
-    __name__[0:-6],
-    "cdk-gitlab-runner@1.75.17.jsii.tgz",
+    "cdk-gitlab-runner", "1.76.1", __name__[0:-6], "cdk-gitlab-runner@1.76.1.jsii.tgz"
 )
 
 __all__ = [
